<?php

namespace FM\Service;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\Remote\FileUploader\Server;
use Zeedhi\Framework\Remote\cURLRequest;

class FileServerService
{
    protected $Environment;
    protected $newCode;
    protected $fileServerApiKeys;
    protected $fileServerUrl;
    protected $FotoTarefaGerChkFactory;
    protected $TarefaGerChkFactory;
    protected $ImgSolicitacaoServFactory;

    public function __construct (Environment $Environment, NewCode $newCode, $fileServerApiKeys, $fileServerUrl) {
        $this->Environment = $Environment;
        $this->newCode = $newCode;
        $this->fileServerApiKeys = $fileServerApiKeys;
        $this->fileServerUrl = $fileServerUrl;
    }

    public function uploadImagem($params, $customFolder) {
        if (isset($this->fileServerApiKeys["20"])) {
            $key = $this->fileServerApiKeys["20"];
            $zhFileUploader = new Server(new cURLRequest($this->fileServerUrl . "/index.php"), $key);
        } else {
            throw new \Exception("Erro ao anexar documento no FileServer: Não existe chave de API parametrizada para o número de organização informado."); 
        }
        
        $row = array('FILE' => $params);
        $zhFileUploader->uploadFilesInRow($row, 'FILE', $customFolder);

        return $row['FILE'][0];
    }
    
    public function uploadImgSolicitacaoServ($files, $nrSol) {
        if (isset($this->fileServerApiKeys["20"])) {
            $key = $this->fileServerApiKeys["20"];
            $zhFileUploader = new Server(new cURLRequest($this->fileServerUrl . "/index.php"), $key);
            $customFolder = "foto_vistoria_fm";
            $row = array('FILE' => $files);
            $zhFileUploader->uploadFilesInRow($row, 'FILE', $customFolder);
            foreach($row['FILE'] as $file) {
                $paramsImg = [
                    "NRSOLICITACAOSERV" => $nrSol,
                    "DSCAMINHO" => $this->fileServerUrl . "/files/" . $file["path"],
                    "DSTYPE" => $file["type"],
                    "NRSIZE" => $file["size"],
                    "NRIMGSOLICITACAOSERV" => $this->newCode->getCodeByTableName('FCM_IMGSOLICITACAOSERV', 20, 1, 10, true)
                ];
                $this->ImgSolicitacaoServFactory->insertImgSolicitacaoServ($paramsImg);
            }
            return $row['FILE'];
        }
    }
    
    public function uploadPictures($params) {
        if (isset($this->fileServerApiKeys["20"])) {
            $key = $this->fileServerApiKeys["20"];
            $zhFileUploader = new Server(new cURLRequest($this->fileServerUrl . "/index.php"), $key);
            $customFolder = "foto_vistoria_fm";
            $paramsTarefaChk = [
                "NRGERENCIAMENTOCHK" => $params["NRGERENCIAMENTOCHK"],
                "NRATIVIDADECHK" => $params["NRATIVIDADECHK"]
            ];
            $tarefaGerChk = $this->TarefaGerChkFactory->joinTarefaChk($paramsTarefaChk)[0];
            $row = array('FILE' => $params['files']);
            $zhFileUploader->uploadFilesInRow($row, 'FILE', $customFolder);
            foreach ($row['FILE'] as $file) {
                $paramsFoto = [
                    "NRFOTOTAREFAGERCHK" => $this->newCode->getCodeByTableName('FCM_TAREFAGERCHK', 20, 1, 10, true),
                    "DSFOTOTAREFAGERCHK" => $this->fileServerUrl . "/files/" . $file["path"],
                    "NRTAREFAGERCHK" => $tarefaGerChk["NRTAREFAGERCHK"],
                    "DSTYPE" => $file["type"],
                    "QTSIZE" => $file["size"]
                ];
                $this->FotoTarefaGerChkFactory->insertFotoTarefaGerChk($paramsFoto);
            }
            return $row['FILE'];
        }
        else {
            throw new \Exception("Erro ao anexar documento no FileServer: Não existe chave de API parametrizada para o número de organização informado.");
        }
    }
    
    public function uploadImagensManut($params) {
        if (isset($this->fileServerApiKeys["20"])) {
            $key = $this->fileServerApiKeys["20"];
            $zhFileUploader = new Server(new cURLRequest($this->fileServerUrl . "/index.php"), $key);
            $customFolder = "foto_manutencao_fm";
            $row = array('FILE' => $params);
            $zhFileUploader->uploadFilesInRow($row, 'FILE', $customFolder);
            $paramsFoto = [];
            foreach ($row['FILE'] as $file) {
                $paramsFoto[] = [
                    "NOME" => $file['name'],
                    "PATH" => $file['path'],
                    "DS" => $this->fileServerUrl . "/files/" . $file["path"],
                    "DSTYPE" => $file["type"],
                    "QTSIZE" => $file["size"]
                ];
            }
            return $paramsFoto;
        }
        else {
            throw new \Exception("Erro ao anexar documento no FileServer: Não existe chave de API parametrizada para o número de organização informado.");
        }
    }
    
    public function downloadFromServer($params) {
        header('Content-Type: application/json; charset =utf-8');
        $typeFile = $params['DSTYPE'];
        $url = $params['DSFOTOTAREFAGERCHK'];
        $splitedString = explode("/", $url);
        $lenSplited = count($splitedString);
        $filename = $splitedString[$lenSplited - 1];
        $content = file_get_contents($url);
        $encodedContent = base64_encode($content);
        $encodedContent = 'data:' . $typeFile . ';base64,' . $encodedContent;
        return $encodedContent;
    }

}

?>