import {
  IDictionary, Http, Metadata, Router,
} from '@zeedhi/core';
import {
  Button, FileInput, Form, LoadingService, Select, TextInput, Textarea,
} from '@zeedhi/common';
import { IterableCarousel, IterableComponentRender } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';
import { FileUpload } from './FileUpload';

export class DashboardController {
  private visibilidadeCarousel: boolean = false;

  public visualizarNovaSolicitacao() {
    Router.replace('/fmtapp_nova_solicitacao_servico');
  }

  public cancelarNovaSolicitacao() {
    this.limpaCampos();
    Router.replace('/fmtapp_dashboard');
  }

  public filtrar({ component }: any) {
    Metadata.getInstance<IterableComponentRender>('iterable-solicitacoes-abertas').datasource.setSearch(component.value);
    Metadata.getInstance<IterableComponentRender>('iterable-ordensServico').datasource.setSearch(component.value);
  }

  public maisQueUmaPagina({ component }: any) {
    component.disabled = !(Metadata.getInstance<IterableComponentRender>(component.name.split('_')[1]).paginationLength > 1);
  }

  public criarCardsOrdensServico() {
    Http.get('/getOrdensServicoDash').then((response: IDictionary) => {
      const dadosOrdens = response.data.data;

      Metadata.getInstance<IterableComponentRender>('iterable-ordensServico').datasource.updateData(dadosOrdens);
    });
  }

  public criarCardsSolicitacoesServico() {
    Http.get('/getSolicitacoesAbertas').then((response: IDictionary) => {
      const dadosSS = response.data.data;

      dadosSS.forEach((elemento: any, pos: number) => {
        dadosSS[pos].COR = (elemento.IDSITUACAO === 'ABERTA') ? 'var(--v-primary-base)' : '#40916c';
      });

      Metadata.getInstance<IterableComponentRender>('iterable-solicitacoes-abertas').datasource.updateData(dadosSS);
    });
  }

  public async saveSolicitacaoServico() {
    const form = Metadata.getInstance<Form>('form-solicitacao-servico');

    if (Utilities.validateForm(form)) {
      const imgs = await this.updloadPictures('fileInputNovaSolicitacao');
      LoadingService.show();
      Http.post('/saveSolicitacaoServico', {
        NMSOLICITACAOSERV: form.value.inputNomeSolicitacao,
        NRCATEGORIAMANUT: form.value.selectServico,
        NREQUIPAMENTO: form.value.selectEquipamento,
        NRIMPACTOMANUT: form.value.selectImpacto,
        DSSOLICITACAOSERV: form.value.textAreaDescricao,
        IMAGENS: imgs,
      }).then(() => {
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        this.cancelarNovaSolicitacao();
        LoadingService.hide();
      });
    }
  }

  public preencheCampos({ component }: any) {
    component.value.inputData = new Date().toLocaleDateString();
  }

  public limpaCampos() {
    Metadata.getInstance<TextInput>('inputNomeSolicitacao').value = null;
    Metadata.getInstance<Select>('selectServico').value = null;
    Metadata.getInstance<Select>('selectEquipamento').value = null;
    Metadata.getInstance<Select>('selectImpacto').value = null;
    Metadata.getInstance<Textarea>('textAreaDescricao').value = null;
    Metadata.getInstance<FileInput>('fileInputNovaSolicitacao').value = null;
  }

  public mostrarFotoSolicitacao({ component }: any) {
    const carouselFotos = Metadata.getInstance<IterableCarousel>('CarouselFotosSolicitacao');
    carouselFotos.iterable.datasource.updateData([]);
    const imagens: any = [];
    component.value.forEach((element: any, pos: any) => {
      imagens.push({
        id: `numero_${pos}`,
        src: window.URL.createObjectURL(element),
      });
    });
    carouselFotos.iterable.datasource.updateData(imagens);
    this.visibilidadeCarousel = component.value.length > 0;
  }

  public async updloadPictures(name: string) {
    const fileInputObject = Metadata.getInstance<FileInput>(name).value;
    let arquivos: any = [];
    if (fileInputObject && fileInputObject.length > 0) {
      const types: IDictionary = ['image/jpg', 'image/jpeg', 'image/png'];
      const buildFilesPromises = fileInputObject.map((file: any) => {
        if (types.includes(file.type)) {
          return FileUpload.buildFileSendObject(file);
        }
        return [];
      });
      await Promise.all(buildFilesPromises).then((files: any) => {
        arquivos = files;
      });
    }
    return arquivos;
  }

  // FUNÇÕES DA TELA DE NOTIFICAÇÕES
  public criarCardsSolicitacoesConvertidas() {
    Http.get('/SolicitacoesConvertidas').then((response: IDictionary) => {
      const dadosSS = response.data.dataset.solicitacoes;

      dadosSS.forEach((elemento: any, pos: number) => {
        if (elemento.IDSITUACAO === 'ABERTA') {
          dadosSS[pos].COR = 'var(--v-primary-base)';
        } else if (elemento.IDSITUACAO === 'EM ANDAMENTO') {
          dadosSS[pos].COR = '#40916c';
        } else if (elemento.IDSITUACAO === 'EM ANÁLISE') {
          dadosSS[pos].COR = '#f3722c';
        } else if (elemento.IDSITUACAO === 'CONCLUÍDA') {
          dadosSS[pos].COR = '#343a40';
        }
      });

      Metadata.getInstance<IterableComponentRender>('iterable-notificacoes-solicitacoesConvertidas').datasource.updateData(dadosSS);
      this.maisQueUmaPagina({
        component: Metadata.getInstance<Button>('proxima-pagina-botao_iterable-notificacoes-solicitacoesConvertidas'),
      });
    });
  }

  public criarCardsOrdensPendentes() {
    Http.get('/OrdensPendente').then((response: IDictionary) => {
      const dadosOS = response.data.dataset.ordens;

      dadosOS.forEach((elemento: any, pos: number) => {
        if (elemento.IDSITUACAOORDEM === 'PENDENTE') {
          dadosOS[pos].COR = '#ff0a54';
        } else if (elemento.IDSITUACAOORDEM === 'EM ANDAMENTO') {
          dadosOS[pos].COR = '#40916c';
        } else if (elemento.IDSITUACAOORDEM === 'CONCLUÍDA') {
          dadosOS[pos].COR = '#343a40';
        }
      });

      Metadata.getInstance<IterableComponentRender>('iterable-ordensServico-pendentes').datasource.updateData(dadosOS);
      this.maisQueUmaPagina({
        component: Metadata.getInstance<Button>('proxima-pagina-botao_iterable-ordensServico-pendentes'),
      });
    });
  }
}
