import Vue from 'vue';
import Router from 'vue-router';
import { Config, Http } from '@zeedhi/core';
import { TekLibLocalStorage, TekLibAuth } from '@zeedhi/tek-lib';
import routes from './routes';
import Store from '../store';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: Config.env.BASE_URL,
  routes,
});

const isOpeningNewModule = function isOpeningNewModule(to: any, from: any) {
  const isFromProduct = (to.name === 'microservice' && from.name !== 'microservice');
  // eslint-disable-next-line max-len
  const isFromAnotherModule = ((to.name === 'microservice' && from.name === 'microservice') && to.path.split('/')[2] !== from.path.split('/')[2]);
  const isNotLoginRoute = (to.fullPath !== Config.env.modules.login.routePath);
  return ((isFromProduct || isFromAnotherModule) && isNotLoginRoute);
};

// eslint-disable-next-line max-len
const callLibStartSessionFromModule = async function callLibStartSessionFromModule(to: any) {
  const data = {
    USER: localStorage.getItem('LOGIN_USER'),
    LOGIN_LANGUAGE: localStorage.getItem('LOGIN_LAGUAGE'),
    LOGIN_TOKEN: localStorage.getItem('LOGIN_TOKEN'),
  };
  await Http.post(`${Config.env.modules[to.path.split('/')[2]].endPoint}/lib_startSession`, data);
};

router.beforeEach(async (to, from, next) => {
  if (isOpeningNewModule(to, from) && TekLibLocalStorage.getItem('IS_NEXT')) {
    await callLibStartSessionFromModule(to);
  }

  TekLibLocalStorage.setItem('IS_NEXT', true);

  TekLibAuth.setInitialData(to.path, Config.env.loginRoutePath);
  if (to.path !== Config.env.loginRoutePath && !localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.loginRoutePath);
  } else if (to.path === Config.env.loginRoutePath && localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.baseUrl);
  } else {
    next();
  }
});

router.afterEach((to, from) => {
  const htmlElement = document.getElementsByTagName('html')[0];
  if (to.name === 'microservice') {
    htmlElement.setAttribute('microservice', '');
    Store.commit('setRouterParams', to.params);
    const frame = (document.getElementById('microservice-frame') as HTMLIFrameElement);
    if (frame && frame.contentWindow && to.path.split('/')[2] === from.path.split('/')[2]) {
      frame.contentWindow.postMessage({
        type: 'microservice-route-change',
        routerParams: to.params,
      }, `${Config.env.modules[to.path.split('/')[2]].baseUrl}`);
    }
    window.document.title = `${Config.env.product.name} - ${to.params.page}`;
  } else {
    htmlElement.removeAttribute('microservice');
    window.document.title = Config.env.product.name;
  }

  if (to.name === 'login') {
    htmlElement.setAttribute('login', '');
  } else {
    htmlElement.removeAttribute('login');
  }
});

export default router;
